Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2)

Unified Diff: chrome/browser/chromeos/fileapi/file_system_backend.h

Issue 243703005: [fsp] [recommit #2] Add an initial AsyncFileUtil. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 6 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/fileapi/file_system_backend.h
diff --git a/chrome/browser/chromeos/fileapi/file_system_backend.h b/chrome/browser/chromeos/fileapi/file_system_backend.h
index df7bff15868400ef6a10683023b08d64f84cec1e..409b36d97e2822701b3616e2372fb6f4da222a3d 100644
--- a/chrome/browser/chromeos/fileapi/file_system_backend.h
+++ b/chrome/browser/chromeos/fileapi/file_system_backend.h
@@ -70,9 +70,11 @@ class FileSystemBackend : public fileapi::ExternalFileSystemBackend {
// FileSystemBackend will take an ownership of a |mount_points|
// reference. On the other hand, |system_mount_points| will be kept as a raw
// pointer and it should outlive FileSystemBackend instance.
// The ownership of |drive_delegate| is also taken.
FileSystemBackend(
FileSystemBackendDelegate* drive_delegate,
+ FileSystemBackendDelegate* file_system_provider_delegate,
scoped_refptr<quota::SpecialStoragePolicy> special_storage_policy,
scoped_refptr<fileapi::ExternalMountPoints> mount_points,
fileapi::ExternalMountPoints* system_mount_points);
@@ -135,9 +137,12 @@ class FileSystemBackend : public fileapi::ExternalFileSystemBackend {
scoped_ptr<FileAccessPermissions> file_access_permissions_;
scoped_ptr<fileapi::AsyncFileUtil> local_file_util_;
- // The Delegate instance for the drive file system related operation.
+ // The delegate instance for the drive file system related operations.
scoped_ptr<FileSystemBackendDelegate> drive_delegate_;
+ // The delegate instance for the provided file system related operations.
+ scoped_ptr<FileSystemBackendDelegate> file_system_provider_delegate_;
+
// Mount points specific to the owning context (i.e. per-profile mount
// points).
//
@@ -70,9 +70,11 @@ class FileSystemBackend : public fileapi::ExternalFileSystemBackend {
// reference. On the other hand, |system_mount_points| will be kept as a raw
// pointer and it should outlive FileSystemBackend instance.
- // The ownership of |drive_delegate| is also taken.
+ // The ownerships of |drive_delegate| and |file_system_provider_delegate| are
+ // also taken.
FileSystemBackend(
FileSystemBackendDelegate* drive_delegate,

Powered by Google App Engine
This is Rietveld 408576698